# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.1.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from robotnikai.models.hmac_algorithm_enum import HmacAlgorithmEnum

class TestHmacAlgorithmEnum(unittest.TestCase):
    """HmacAlgorithmEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testHmacAlgorithmEnum(self):
        """Test HmacAlgorithmEnum"""
        # inst = HmacAlgorithmEnum()

if __name__ == '__main__':
    unittest.main()
